@@ -8,11 +8,13 @@ from .stream import Stream
 
 class Parser:  # mb: we don't need Parser itself. its just storage for links and tags. Hm...
     def __init__(self, implicit_fstrings: bool = True,
-                 strict: bool = False):
+                 strict: bool = False,
+                 sequential_links: bool = False):
         self.links = []
         self.iterators = []
         self.implicit_fstrings = implicit_fstrings
         self.strict = strict
+        self.sequential_links = sequential_links
         self.last_indent = -1
 
     def parse(self, path: Union[str, Path]):
@@ -27,7 +29,10 @@ class Parser:  # mb: we don't need Parser itself. its just storage for links and
 
     def parse_string(self, string):
         stream = Stream(string)  # mb: add stream to parser and log errors more convenient
-        return elements.Document.read(stream, self)
+        tree = elements.Document.read(stream, self)
+        if stream:
+            raise ParserError(stream, "Wrong statement.")
+        return tree
 
     def has_iterators(self) -> bool:
         return len(self.iterators) > 0
